#[repr(u8)]pub enum Datainsel {
ORIG_FLEX_I2S_SIGNALS = 0,
SHARED_SET0_I2S_SIGNALS = 1,
SHARED_SET1_I2S_SIGNALS = 2,
_RESERVED_3 = 3,
}Variants
ORIG_FLEX_I2S_SIGNALS = 0
Selects the dedicated FCn_RXD_SDA_MOSI_DATA input for this Flexcomm.
SHARED_SET0_I2S_SIGNALS = 1
Input data is taken from shared signal set 0 (defined by SHAREDCTRLSET0).
SHARED_SET1_I2S_SIGNALS = 2
Input data is taken from shared signal set 1 (defined by SHAREDCTRLSET1).
_RESERVED_3 = 3
Implementations