#[repr(u8)]pub enum Sharedwssel {
FLEXCOMM0 = 0,
FLEXCOMM1 = 1,
FLEXCOMM2 = 2,
FLEXCOMM3 = 3,
FLEXCOMM4 = 4,
FLEXCOMM5 = 5,
FLEXCOMM6 = 6,
FLEXCOMM7 = 7,
}Variants
FLEXCOMM0 = 0
WS for this shared signal set comes from Flexcomm 0.
FLEXCOMM1 = 1
WS for this shared signal set comes from Flexcomm 1.
FLEXCOMM2 = 2
WS for this shared signal set comes from Flexcomm 2.
FLEXCOMM3 = 3
WS for this shared signal set comes from Flexcomm 3.
FLEXCOMM4 = 4
WS for this shared signal set comes from Flexcomm 4.
FLEXCOMM5 = 5
WS for this shared signal set comes from Flexcomm 5.
FLEXCOMM6 = 6
WS for this shared signal set comes from Flexcomm 6.
FLEXCOMM7 = 7
WS for this shared signal set comes from Flexcomm 7.
Implementations